@@ -125,7 +125,7 @@ use Time::HiRes qw(gettimeofday);
 
 Creates a new event loop ready for monitoring file handles, or
 generating timeouts. Except in very unsual circumstances (examples
-of which I can't think up) it is not neccessary or desriable to
+of which I can't think up) it is not necessary or desriable to
 explicitly create new reactor instances. Instead call the L<main>
 method to get a handle to the singleton instance.
 
@@ -225,7 +225,7 @@ sub manage {
 	    my $timeout = shift;
 	
 	    my $key = $timeout->get_data;
-	    $self->remove_timeout($key,
+	    $self->toggle_timeout($key,
 				  $timeout->is_enabled,
 				  $timeout->get_interval);
 	});
@@ -373,7 +373,7 @@ sub step {
     my $n = select($ro=$ri,$wo=$wi,$eo=$ei, (defined $timeout ? ($timeout ? $timeout/1000 : 0) : undef));
 
     @callbacks = ();
-    if ($n) {
+    if ($n > 0) {
 	push @callbacks, $self->_dispatch_fd("read", $ro);
 	push @callbacks, $self->_dispatch_fd("write", $wo);
 	push @callbacks, $self->_dispatch_fd("error", $eo);
@@ -597,7 +597,7 @@ sub remove_timeout {
 =item $reactor->toggle_timeout($id, $status[, $interval]);
 
 Updates the state of a previously registered timeout
-specifed by the C<$id> parameter. The C<$status>
+specified by the C<$id> parameter. The C<$status>
 parameter specifies whether the timeout is to be enabled
 or disabled, while the optional C<$interval> parameter
 can be used to change the period of the timeout.
